import { EventEmitter, OnDestroy, OnInit, Renderer2, TemplateRef, ViewContainerRef } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { NrfSubmitData } from './form-submit-data.class';
import { NrfFormService } from './form.service';
/**
 * A component to abstract the form implementation
 *
 * It holds the validation and the submit logic
 *
 * @example
 * <form nrfForm (nrfSubmit)="aCallback($event)">
 *  // Inputs
 * </form>
 */
export declare class NrfFormDirective implements OnInit, OnDestroy {
    private readonly templateRef;
    private readonly viewContainerRef;
    private readonly formService;
    private renderer;
    /**
     * @ignore
     */
    constructor(templateRef: TemplateRef<any>, viewContainerRef: ViewContainerRef, formService: NrfFormService, renderer: Renderer2);
    /**
     * Represents an Entity Model that comes from Database
     */
    nrfEntity: any;
    readonly formData: any;
    readonly formGroup: FormGroup;
    /**
     * A function that will be called when the form is valid and a submit event is triggered
     * by a button click or programmatically.
     */
    readonly nrfSubmit: EventEmitter<NrfSubmitData>;
    /**
     * Init an empty nrfEntity, in case none where provided.
     */
    ngOnInit(): void;
    ngOnDestroy(): void;
    private renderView();
    /**
     * # Should not be called directly!
     * This method wraps the form validation and call [nrfSubmit]{@link NrfFormDirective#nrfSubmit}
     */
    formSubmitWrapper($event: Event): void;
}
